@@ -4,10 +4,20 @@ use Moose;
 use MooseX::Attribute::ENV;
 use Pod::Find ();
 use Pod::Usage ();
-use DBIx::Class::Migration::Types 'LoadableClass', 'ArraySQLTProducers';
+use DBIx::Class::Migration::Types qw(
+  LoadableClass ArraySQLTProducers AbsolutePath
+);
+use Log::Any;
+use Carp 'croak';
 
 with 'MooseX::Getopt';
 
+sub _log_die {
+  my ($self, $msg) = @_;
+  $self->log->error($msg);
+  croak $msg;
+}
+
 sub ENV_PREFIX {
   $ENV{DBIC_MIGRATION_ENV_PREFIX}
     || 'DBIC_MIGRATION';
@@ -19,6 +29,12 @@ use constant {
   SANDBOX_POSTGRESQL => 'PostgresqlSandbox',
 };
 
+has log => (
+    is  => 'ro',
+    isa => 'Log::Any::Proxy',
+    default => sub { Log::Any->get_logger( category => 'DBIx::Class::Migration') },
+);
+
 has includes => (
   traits => ['Getopt'],
   is => 'ro',
@@ -31,7 +47,8 @@ has schema => (is=>'ro', predicate=>'has_schema');
 has schema_class => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
   predicate=>'has_schema_class', env_prefix=>ENV_PREFIX, cmd_aliases => 'S');
 
-has target_dir => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa=> 'Str',
+has target_dir => (traits => [ 'Getopt', 'ENV' ],
+  is => 'ro', isa=> AbsolutePath, coerce => 1,
   predicate=>'has_target_dir', env_prefix=>ENV_PREFIX, cmd_aliases => 'dir');
 
 has sandbox_dir => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa=> 'Str',
@@ -55,10 +72,7 @@ has to_version => (traits => [ 'Getopt' ], is => 'ro', isa => 'Int',
 has sql_translator_args => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
   predicate=>'has_sql_translator_args');
 
-# When register with MooseX::Getopt::OptionTypeMap->add_option_type_to_map,
-# stores with long name. has_option_type looks up with literal name in
-# attr declaration, so must match.
-has databases => (traits => [ 'Getopt' ], is => 'ro', isa => 'DBIx::Class::Migration::_Types::ArraySQLTProducers',
+has databases => (traits => [ 'Getopt' ], is => 'ro', isa => ArraySQLTProducers,
   predicate=>'has_databases', cmd_aliases => 'database');
 
 has sandbox_class => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
@@ -235,7 +249,7 @@ sub run {
     foreach my $cmd ($argv, @extra_argv) {
       $self->can("cmd_${cmd}") ?
         $self->${\"cmd_${cmd}"} :
-        die "No such command ${cmd}\n";
+        $self->_log_die( "No such command ${cmd}\n" );
     }
 
   }
@@ -427,9 +441,9 @@ Accepts ArrayRef.  Not Required.
 
 Used when building L</migration> to define the target databases we are building
 migration files for.  You can name any of the databases currently supported by
-L<SQLT>.  If you leave this undefined we will derive a value based on the value
+L<SQL::Translator>.  If you leave this undefined we will derive a value based on the value
 of L</dsn>.  For example, if your L</dsn> is "DBI:SQLite:test.db", we will set
-the valuye of L</databases> to C<['SQLite']>.
+the value of L</databases> to C<['SQLite']>.
 
 =head2 sql_translator_args
 
